@@ -5,6 +5,7 @@
 #
 import grpc
 import threading
+from copy import deepcopy
 from gettext import gettext as _
 
 from astersay.backends.base import Listener
@@ -21,13 +22,15 @@ class TinkoffRecognizer(TinkoffBaseBackend):
     # Счётчик текущих предварительных результатов. Сбрасывается финальным.
     partials_counter = 0
 
-    def __init__(self, settings):
+    def __init__(self, settings, extra=None):
         TinkoffBaseBackend.__init__(self)
         self.set_token_manager(settings)
 
         conf = settings.tinkoff
 
-        recognizer = conf['recognizer']
+        recognizer = deepcopy(conf['recognizer'])
+        if extra:
+            recognizer.update(extra)
 
         language = recognizer['language_code']
         assert language in self.LANGUAGES
