@@ -249,6 +249,7 @@ def create_dirs(work_dir):
     dirs = (
         path_join(work_dir, 'config'),
         path_join(work_dir, 'dialogs'),
+        path_join(work_dir, 'modules'),
         path_join(work_dir, 'logs'),
         path_join(work_dir, 'export'),
         path_join(work_dir, 'plugins'),
@@ -526,8 +527,12 @@ class Settings:
     def configure(self):
         self.work_dir = work_dir = abspath(self.work_dir or DEFAULT_WORK_DIR)
         create_dirs(work_dir)
+        # TODO: в версии 0.30 убрать `dialogs` в пользу `modules`
         # Каталог, где не только диалоги, но и импортируемые классы диалогов.
         sys.path.append(path_join(work_dir, 'dialogs'))
+        # Каталог для импортируемых модулей, содержищих классы диалогов и
+        # другие необходимые для расширения функционала вещи.
+        sys.path.append(path_join(work_dir, 'modules'))
 
         self.main = get_main_config(work_dir)
         self.logging = get_logging_config(work_dir)
